@@ -323,7 +323,7 @@ MultiAssayExperiment <-
 ### Validity
 ###
 
-## ELIST
+## EXPERIMENTLIST
 ## 1.i. ExperimentList length must be the same as the unique length of the
 ## sampleMap "assay" column.
 .checkExperimentList <- function(object) {
@@ -561,9 +561,8 @@ setMethod("names", "MultiAssayExperiment", function(x)
 ###
 
 #' @export
-setGeneric("sampleMap<-", function(object, value) {
-    standardGeneric("sampleMap<-")
-})
+setGeneric("sampleMap<-", function(object, value)
+    standardGeneric("sampleMap<-"))
 
 #' @exportMethod sampleMap<-
 #' @rdname MultiAssayExperiment-methods
@@ -611,14 +610,25 @@ setReplaceMethod("experiments", c("MultiAssayExperiment", "ExperimentList"),
         }
         o_cnames <- colnames(object)
         v_cnames <- colnames(value)
-        if (identical(o_cnames, v_cnames))
+        if (identical(o_cnames, v_cnames)) {
             BiocBaseUtils::setSlots(
                 object = object,
                 ExperimentList = value,
                 check = FALSE
             )
-        else {
-            rebliss <- .harmonize(value, colData(object), sampleMap(object))
+        } else {
+
+            samplemap <- sampleMap(object)
+
+            if (all(names(o_cnames) %in% names(v_cnames))) {
+                levels <- names(v_cnames)
+                ordernames <- names(Filter(length, v_cnames))
+                samplemap <- listToMap(mapToList(samplemap)[ordernames])
+                samplemap[["assay"]] <-
+                    factor(samplemap[["assay"]], levels = levels)
+            }
+
+            rebliss <- .harmonize(value, colData(object), samplemap)
 
             BiocBaseUtils::setSlots(
                 object = object,
