@@ -173,3 +173,35 @@ test_that("replace methods are using rebliss and replace", {
         colnames(mae0), as(cc, "CompressedCharacterList")
     )
 })
+
+test_that("re-ordering is working properly", {
+    mae0 <- mae
+    mae0 <- mae0[, , c(2, 3, 1, 4)]
+    newnameorder <- names(mae)[c(2, 3, 1, 4)]
+    expect_identical(
+        names(mae0), newnameorder
+    )
+    expect_identical(
+        levels(sampleMap(mae0)[["assay"]]), newnameorder
+    )
+    map <- sampleMap(mae)
+    smap <- mapToList(map)
+    nmap <- listToMap(smap[newnameorder])
+    expect_identical(
+        sampleMap(mae0), nmap
+    )
+
+    m1 <- matrix(0, 3, 3, dimnames=list(letters[1:3], letters[1:3]))
+    m2 <- matrix(0, 0, 0)
+    m3 <- matrix(0, 1, 1, dimnames=list("d", "d"))
+    obs <- MultiAssayExperiment(list(m1=m1, m2=m2, m3=m3))
+    obs[["m1"]] <- obs[["m1"]][, c("a", "b")]
+    ## expect no assay drops
+    expect_identical(
+        names(obs), paste0("m", 1:3)
+    )
+    ## levels should be preserved
+    expect_identical(
+        levels(sampleMap(obs)[["assay"]]), paste0("m", 1:3)
+    )
+})
